@@ -1,9 +1,11 @@
 package Acme::CPANModules::HidingModules;
 
+use strict;
+
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-04-30'; # DATE
+our $DATE = '2023-10-29'; # DATE
 our $DIST = 'Acme-CPANModules-HidingModules'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 our $text = <<'_';
 
@@ -73,7 +75,7 @@ the module files. <pm:App::pmhiderename> and <lib::hiderename> does this.
 _
 
 our $LIST = {
-    summary => 'Hiding modules',
+    summary => 'List of modules to hide other modules',
     description => $text,
     tags => ['task'],
     entries => [
@@ -86,7 +88,7 @@ our $LIST = {
 
 
 1;
-# ABSTRACT: Hiding modules
+# ABSTRACT: List of modules to hide other modules
 
 __END__
 
@@ -96,11 +98,11 @@ __END__
 
 =head1 NAME
 
-Acme::CPANModules::HidingModules - Hiding modules
+Acme::CPANModules::HidingModules - List of modules to hide other modules
 
 =head1 VERSION
 
-This document describes version 0.004 of Acme::CPANModules::HidingModules (from Perl distribution Acme-CPANModules-HidingModules), released on 2020-04-30.
+This document describes version 0.005 of Acme::CPANModules::HidingModules (from Perl distribution Acme-CPANModules-HidingModules), released on 2023-10-29.
 
 =head1 DESCRIPTION
 
@@ -163,40 +165,74 @@ To fool code that tries to find the module files themselves without using any
 module, i.e. by iterating @INC, you will need to actually (temporarily) rename
 the module files. L<App::pmhiderename> and <lib::hiderename> does this.
 
-=head1 INCLUDED MODULES
+=head1 ACME::CPANMODULES ENTRIES
 
 =over
 
-=item * L<lib::filter>
+=item L<lib::filter>
 
-=item * L<lib::disallow>
+Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
 
-=item * L<Devel::Hide>
+=item L<lib::disallow>
 
-=item * L<Test::Without::Module>
+Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
 
-=item * L<Module::Path::Patch::Hide>
+=item L<Devel::Hide>
 
-=item * L<Module::Path::More::Patch::Hide>
+Author: L<DCANTRELL|https://metacpan.org/author/DCANTRELL>
 
-=item * L<Module::List::Patch::Hide>
+=item L<Test::Without::Module>
 
-=item * L<PERLANCAR::Module::List::Patch::Hide>
+Author: L<CORION|https://metacpan.org/author/CORION>
 
-=item * L<Module::List::Tiny::Patch::Hide>
+=item L<Module::Path::Patch::Hide>
 
-=item * L<Module::List::Wildcard::Patch::Hide>
+Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
 
-=item * L<App::pmhiderename>
+=item L<Module::Path::More::Patch::Hide>
+
+Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
+
+=item L<Module::List::Patch::Hide>
+
+Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
+
+=item L<PERLANCAR::Module::List::Patch::Hide>
+
+Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
+
+=item L<Module::List::Tiny::Patch::Hide>
+
+Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
+
+=item L<Module::List::Wildcard::Patch::Hide>
+
+Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
+
+=item L<App::pmhiderename>
+
+Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
 
 =back
 
 =head1 FAQ
 
-=head2 What are ways to use this module?
+=head2 What is an Acme::CPANModules::* module?
 
-Aside from reading it, you can install all the listed modules using
-L<cpanmodules>:
+An Acme::CPANModules::* module, like this module, contains just a list of module
+names that share a common characteristics. It is a way to categorize modules and
+document CPAN. See L<Acme::CPANModules> for more details.
+
+=head2 What are ways to use this Acme::CPANModules module?
+
+Aside from reading this Acme::CPANModules module's POD documentation, you can
+install all the listed modules (entries) using L<cpanm-cpanmodules> script (from
+L<App::cpanm::cpanmodules> distribution):
+
+ % cpanm-cpanmodules -n HidingModules
+
+Alternatively you can use the L<cpanmodules> CLI (from L<App::cpanmodules>
+distribution):
 
     % cpanmodules ls-entries HidingModules | cpanm -n
 
@@ -204,9 +240,15 @@ or L<Acme::CM::Get>:
 
     % perl -MAcme::CM::Get=HidingModules -E'say $_->{module} for @{ $LIST->{entries} }' | cpanm -n
 
-This module also helps L<lcpan> produce a more meaningful result for C<lcpan
-related-mods> when it comes to finding related modules for the modules listed
-in this Acme::CPANModules module.
+or directly:
+
+    % perl -MAcme::CPANModules::HidingModules -E'say $_->{module} for @{ $Acme::CPANModules::HidingModules::LIST->{entries} }' | cpanm -n
+
+This Acme::CPANModules module also helps L<lcpan> produce a more meaningful
+result for C<lcpan related-mods> command when it comes to finding related
+modules for the modules listed in this Acme::CPANModules module.
+See L<App::lcpan::Cmd::related_mods> for more details on how "related modules"
+are found.
 
 =head1 HOMEPAGE
 
@@ -216,14 +258,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANM
 
 Source repository is at L<https://github.com/perlancar/perl-Acme-CPANModules-HidingModules>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANModules-HidingModules>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Acme::CPANModules> - about the Acme::CPANModules namespace
@@ -234,11 +268,37 @@ L<cpanmodules> - CLI tool to let you browse/view the lists
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2019 by perlancar@cpan.org.
+This software is copyright (c) 2023, 2020, 2019 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANModules-HidingModules>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
